# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cell.proto
# Protobuf Python Version: 6.32.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    1,
    '',
    'cell.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import location_pb2 as location__pb2
from . import world_object_pb2 as world__object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ncell.proto\x12\x05\x61\x65gis\x1a\x0elocation.proto\x1a\x12world_object.proto\"\x89\x01\n\x04\x43\x65ll\x12\x1c\n\x03loc\x18\x01 \x01(\x0b\x32\x0f.aegis.Location\x12\x10\n\x08moveCost\x18\x02 \x01(\x05\x12\x1d\n\x04type\x18\x03 \x01(\x0e\x32\x0f.aegis.CellType\x12\x0e\n\x06\x61gents\x18\x04 \x03(\x05\x12\"\n\x06layers\x18\x05 \x03(\x0b\x32\x12.aegis.WorldObject*;\n\x08\x43\x65llType\x12\n\n\x06NORMAL\x10\x00\x12\t\n\x05SPAWN\x10\x01\x12\n\n\x06KILLER\x10\x02\x12\x0c\n\x08\x43HARGING\x10\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cell_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CELLTYPE']._serialized_start=197
  _globals['_CELLTYPE']._serialized_end=256
  _globals['_CELL']._serialized_start=58
  _globals['_CELL']._serialized_end=195
# @@protoc_insertion_point(module_scope)
